from __future__ import annotations
from pydantic import BaseModel
from UPS_SDK.models.StatusType import StatusType
from UPS_SDK.models.StatusCode import StatusCode
class Status(BaseModel):
    StatusType: StatusType
    StatusCode: StatusCode


from __future__ import annotations
from pydantic import BaseModel
from UPS_SDK.models.UnitOfMeasurement1 import UnitOfMeasurement1
class PackageWeight(BaseModel):
    UnitOfMeasurement: UnitOfMeasurement1
    Weight: str


from __future__ import annotations
from pydantic import BaseModel
from UPS_SDK.models.Response import Response
from UPS_SDK.models.Shipment import Shipment

class TrackResponse(BaseModel):
    Response: Response
    Shipment: Shipment